@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.8.3
+ *             Automatically Tuned Linear Algebra Software v3.10.3
  *                    (C) Copyright 1999 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -87,15 +87,11 @@ void cblas_cgbmv(const enum CBLAS_ORDER Order, const enum CBLAS_TRANSPOSE TA,
       if (incY < 0) y += (1-N)*incY<<1;
    }
    if (Order == CblasColMajor)
-   {
-      if (TA == CblasNoTrans)
-         ATL_cgbmv(TA, M, N, KL, KU, alpha, A, lda, x, incX, beta, y, incY);
-      else ATL_cgbmv(TA, N, M, KL, KU, alpha, A, lda, x, incX, beta, y, incY);
-   }
+      ATL_cgbmv(TA, M, N, KL, KU, alpha, A, lda, x, incX, beta, y, incY);
    else
    {
       if (TA == CblasNoTrans)
-         ATL_cgbmv(CblasTrans, M, N, KU, KL, alpha, A, lda, x, incX,
+         ATL_cgbmv(CblasTrans, N, M, KU, KL, alpha, A, lda, x, incX,
                    beta, y, incY);
       else if (TA == CblasConjTrans)
          ATL_cgbmv(AtlasConj, N, M, KU, KL, alpha, A, lda, x, incX,
