@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.8.3
+ *             Automatically Tuned Linear Algebra Software v3.10.3
  *                    (C) Copyright 1999 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -47,6 +47,8 @@ TYPE Mjoin(PATL,gediffnrm1)
       t0 = ATL_rzero;
       for (i=0; i != M2; i++) t0 += Mabs(A[i] - B[i]);
       if (t0 > max) max = t0;
+      if (t0 != t0)   /* if we've got a NaN */
+         return(t0);  /* report it as norm! */
       A += lda2;
       B += ldb2;
    }
